@@ -1,5 +1,3 @@
-
-
 #include <qpdf/BitStream.hh>
 
 // See comments in bits.cc
@@ -36,7 +34,8 @@ BitStream::skipToNextByte()
 	unsigned int bits_to_skip = bit_offset + 1;
 	if (bits_available < bits_to_skip)
 	{
-	    throw QEXC::Internal("overflow skipping to next byte in bitstream");
+	    throw std::logic_error(
+		"INTERNAL ERROR: overflow skipping to next byte in bitstream");
 	}
 	bit_offset = 7;
 	++p;
