@@ -1,6 +1,4 @@
-
 #include <qpdf/Pl_RC4.hh>
-
 #include <qpdf/QUtil.hh>
 
 Pl_RC4::Pl_RC4(char const* identifier, Pipeline* next,
@@ -27,7 +25,7 @@ Pl_RC4::write(unsigned char* data, int len)
 {
     if (this->outbuf == 0)
     {
-	throw Exception(
+	throw std::logic_error(
 	    this->identifier +
 	    ": Pl_RC4: write() called after finish() called");
     }
