@@ -246,6 +246,13 @@ QPDFObjectHandle::getArrayItem(int n)
     return dynamic_cast<QPDF_Array*>(obj.getPointer())->getItem(n);
 }
 
+std::vector<QPDFObjectHandle>
+QPDFObjectHandle::getArrayAsVector()
+{
+    assertType("Array", isArray());
+    return dynamic_cast<QPDF_Array*>(obj.getPointer())->getAsVector();
+}
+
 // Array mutators
 
 void
@@ -278,6 +285,13 @@ QPDFObjectHandle::getKeys()
     return dynamic_cast<QPDF_Dictionary*>(obj.getPointer())->getKeys();
 }
 
+std::map<std::string, QPDFObjectHandle>
+QPDFObjectHandle::getDictAsMap()
+{
+    assertType("Dictionary", isDictionary());
+    return dynamic_cast<QPDF_Dictionary*>(obj.getPointer())->getAsMap();
+}
+
 // Array and Name accessors
 bool
 QPDFObjectHandle::isOrHasName(std::string const& value)
