@@ -246,9 +246,9 @@ QPDF::optimizePagesTree(
 	    {
 		if (! allow_changes)
 		{
-		    throw QPDFExc(qpdf_e_internal, this->file.getName(),
+		    throw QPDFExc(qpdf_e_internal, this->file->getName(),
 				  this->last_object_description,
-				  this->file.getLastOffset(),
+				  this->file->getLastOffset(),
 				  "optimize detected an "
 				  "inheritable resource when called "
 				  "in no-change mode");
@@ -354,9 +354,9 @@ QPDF::optimizePagesTree(
     }
     else
     {
-	throw QPDFExc(qpdf_e_damaged_pdf, this->file.getName(),
+	throw QPDFExc(qpdf_e_damaged_pdf, this->file->getName(),
 		      this->last_object_description,
-		      this->file.getLastOffset(),
+		      this->file->getLastOffset(),
 		      "invalid Type in page tree");
     }
 }
